@@ -23,6 +23,14 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+  /*
+     Fixes:
+
+     Add -r flag: Keith Owens <kaos@ocs.com.au> October 1999.
+   */
+
+#ident "$Id: depmod.c 1.3 Tue, 12 Oct 1999 20:53:21 +1000 keith $"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <getopt.h>
@@ -551,6 +559,7 @@ static void usage()
 	"Option -v force a printout of all visited modules.\n"
 	"Option -n will write the dependency file on stdout only.\n"
 	"Option -V will show you the release version of depmod\n"
+	"Option -r will allow root to load modules that are not owned by root\n"
 	"\n"
 	"The following options are useful for people managing distributions;\n"
 	"Option '-b basedirectory': use an image of a module tree.\n"
@@ -582,12 +591,13 @@ int main(int argc, char *argv[])
 		{"syslog", 0, 0, 's'},
 		{"verbose", 0, 0, 'v'},
 		{"version", 0, 0, 'V'},
+		{"root", 0, 0, 'r'},
 		{0, 0, 0, 0 }
 	};
 
 	error_file = "depmod";
 
-	while ((o = getopt_long(argc, argv, "ab:C:eF:hnqsvV",
+	while ((o = getopt_long(argc, argv, "ab:C:eF:hnqsvVr",
 				&long_opts[0], NULL)) != EOF) {
 		switch (o) {
 		case 'a':
@@ -636,6 +646,10 @@ int main(int argc, char *argv[])
 			printf("depmod version %s\n", MODUTILS_VERSION);
 			break;
 
+		case 'r':
+			root_check_off = 1;
+			break;
+
 		default:
 			err = 1;
 			break;
