@@ -33,9 +33,11 @@
      SMP "friendliness" (and -P): Bill Zumach <zumach+@transarc.com>
 
      Ksymoops support: Keith Owens <kaos@ocs.com.au> August 1999.
+
+     Add -r flag: Keith Owens <kaos@ocs.com.au> October 1999.
    */
 
-#ident "$Id: insmod.c 1.4 Thu, 02 Sep 1999 03:26:13 +1000 keith $"
+#ident "$Id: insmod.c 1.5 Tue, 12 Oct 1999 20:53:21 +1000 keith $"
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -1070,6 +1072,7 @@ static void usage(void)
 	      "  -X                    Do export externs (default)\n"
 	      "  -y                    Do not add ksymoops symbols\n"
 	      "  -Y                    Do add ksymoops symbols (default)\n"
+	      "  -r                    Allow root to load modules not owned by root\n"
 	      "  -P PREFIX\n"
 	      "      --prefix=PREFIX   Prefix for kernel or module symbols\n"
 	      ,stderr);
@@ -1098,6 +1101,7 @@ int main(int argc, char **argv)
 		{"quiet", 0, 0, 'q'},
 		{"noksymoops", 0, 0, 'y'},
 		{"ksymoops", 0, 0, 'Y'},
+		{"root", 0, 0, 'r'},
 		{0, 0, 0, 0}
 	};
 	char *m_name = NULL;
@@ -1122,7 +1126,7 @@ int main(int argc, char **argv)
 	errors = optind = 0;
 
 	/* Process the command line.  */
-	while ((o = getopt_long(argc, argv, "fkmno:pqsvVxXLP:yY",
+	while ((o = getopt_long(argc, argv, "fkmno:pqsvVxXLP:yYr",
 				&long_opts[0], NULL)) != EOF)
 		switch (o) {
 		case 'f':	/* force loading */
@@ -1170,6 +1174,9 @@ int main(int argc, char **argv)
 		case 'Y':	/* do define ksymoops symbols */
 			flag_ksymoops = 1;
 			break;
+		case 'r':	/* allow root to load non-root modules */
+			root_check_off = 1;
+			break;
 		case 'P':	/* use prefix on crc */
 			set_ncv_prefix(optarg);
 			break;
