@@ -176,8 +176,8 @@ static const char *any_alias(const char *mod)
 	int i;
 
 	/*
-	 * Specification: /etc/conf.modules / alias / format
-	 * The format of the alias command in /etc/conf.modules is
+	 * Specification: /etc/modules.conf / alias / format
+	 * The format of the alias command in /etc/modules.conf is
 	 *	alias alias_name module_name
 	 */
 	/* For devfs */
@@ -357,7 +357,7 @@ static int build_stack(LINK **stack, const char *name, const char *objname, int
 
 	/*
 	 * Get the modules that this one should pull in
-	 * according to conf.modules ("above")
+	 * according to modules.conf ("above")
 	 * Handle all levels of aliases (from desc->name)
 	 */
 	for (lp = desc->name; lp; lp = lp->next) {
@@ -401,7 +401,7 @@ static int build_stack(LINK **stack, const char *name, const char *objname, int
 
 	/*
 	 * Get the modules that this one depends on
-	 * according to conf.modules ("below")
+	 * according to modules.conf ("below")
 	 * Handle all levels of aliases (from desc->name)
 	 */
 	for (lp = desc->name; lp; lp = lp->next) {
@@ -731,14 +731,13 @@ static int read_depfile(void)
 		return -1;
 	}
 
-#define EXTREMELY_CATIOUS
-#ifdef EXTREMELY_CATIOUS
+#define EXTREMELY_CAUTIOUS
+#ifdef EXTREMELY_CAUTIOUS
 	if (fstat(fileno(fin), &statbuf) != 0)
 		error("Could not stat %s", depfile);
 	else if (config_mtime && config_mtime > statbuf.st_mtime)
 		lprintf("Note: %s is more recent than %s",
-			(conf_file ? conf_file : "/etc/conf.modules"),
-			depfile);
+			config_file, depfile);
 #endif
 
 	while (fgets_strip(buf, sizeof(buf) - 1, fin, &line_no) != NULL) {
@@ -1388,7 +1387,7 @@ static void usage(void)
 		"\t-t, --type moduletype      Only look for modules of this type\n"
 		"\t-v, --verbose              Print all commands\n"
 		"\t-V, --version              Show version\n"
-		"\t-C, --config configfile    Use instead of /etc/conf.modules\n"
+		"\t-C, --config configfile    Use instead of /etc/modules.conf\n"
 	    );
 }
 
@@ -1523,7 +1522,7 @@ int main(int argc, char *argv[])
 			/*
 			 * Clean up "autoclean" modules, allowing the
 			 * use of any pre-/post-remove entries in
-			 * /etc/conf.modules
+			 * /etc/modules.conf
 			 *
 			 * This means that the kerneld autoremoval can
 			 * be replaced with "modprobe -r" via crontab.
