@@ -96,9 +96,10 @@ static int n_aliases;
 
 char *insmod_opt = NULL;
 char *depfile = NULL;
-char *config_file = NULL;    /* Which file was actually used */
+char *config_file = NULL;	/* Which file was actually used */
 time_t config_mtime;
-static char *config_version; /* Hack for config_add */
+int root_check_off = 0;		/* Default, modules must be owned by root */
+static char *config_version;	/* Hack for config_add */
 
 /*
  *	Strip white char at the end of a string.
@@ -578,10 +579,14 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
 			/* Fall back to non-standard name */
 			if ((fin = fopen((conf_file = old_name), "r"))) {
 				fprintf(stderr,
-					"Warning: modutils is reading from %s because %s\n"
-					"         does not exist.  The use of %s is depreciated, please rename\n"
-					"         %s to %s as soon as possible.\n",
-					old_name, ETC_MODULES_CONF, old_name, old_name, ETC_MODULES_CONF);
+					"Warning: modutils is reading from %s because\n"
+					"         %s does not exist.  The use of %s is\n"
+					"         depreciated, please rename %s to %s\n"
+					"         as soon as possible.  Command\n"
+					"         mv %s %s\n",
+					old_name, ETC_MODULES_CONF,
+					old_name, old_name, ETC_MODULES_CONF,
+					old_name, ETC_MODULES_CONF);
 			}
 			/* So what... use the default configuration */
 		}
@@ -601,23 +606,35 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
 				if (lstat(ETC_MODULES_CONF, &statbuf1) == 0 &&
 				    S_ISLNK(statbuf1.st_mode))
 					fprintf(stderr,
-						"Warning: You do not need a link from %s to %s.\n"
-						"         The use of %s is depreciated, please remove %s\n"
-						"         and rename %s to %s as soon as possible.\n",
-						ETC_MODULES_CONF, old_name, old_name, ETC_MODULES_CONF, old_name, ETC_MODULES_CONF);
+						"Warning: You do not need a link from %s to\n"
+						"         %s.  The use of %s is depreciated,\n"
+						"         please remove %s and rename %s\n" 
+						"         to %s as soon as possible.  Commands.\n"
+						"           rm %s\n"
+						"           mv %s %s\n",
+						ETC_MODULES_CONF, old_name,
+						old_name, ETC_MODULES_CONF, old_name, ETC_MODULES_CONF,
+						ETC_MODULES_CONF,
+						old_name, ETC_MODULES_CONF);
 				else
 					fprintf(stderr,
-						"Warning: You do not need a link from %s to %s.\n"
-						"         The use of %s is depreciated, please remove %s\n"
-						"         as soon as possible.\n",
-						old_name, ETC_MODULES_CONF, old_name, old_name);
+						"Warning: You do not need a link from %s to\n"
+						"         %s.  The use of %s is depreciated,\n"
+						"         please remove %s as soon as possible.  Command\n"
+						"           rm %s\n",
+						old_name, ETC_MODULES_CONF,
+						old_name, old_name,
+						old_name);
 				}
 			else
 				fprintf(stderr,
-					"Warning: modutils is reading from %s and ignoring %s.\n"
-					"         The use of %s is depreciated, please remove %s\n"
-					"         as soon as possible.\n",
-					ETC_MODULES_CONF, old_name, old_name, old_name);
+					"Warning: modutils is reading from %s and\n"
+					"         ignoring %s.  The use of %s is depreciated,\n"
+					"         please remove %s as soon as possible.  Command\n"
+					"           rm %s\n",
+					ETC_MODULES_CONF, old_name,
+					old_name, old_name,
+					old_name);
 		}
 	}
 
@@ -1231,9 +1248,11 @@ static int config_add(const char *file, const struct stat *sb, int flag)
 			int j;
 			char **this;
 
-			if (sb->st_uid != 0) {
-				error("%s is not owned by root", paths[i]);
-				continue;
+			if (!root_check_off) {
+				if (sb->st_uid != 0) {
+					error("%s is not owned by root", paths[i]);
+					continue;
+				}
 			}
 
 			/* avoid duplicates */
